authenticate

Function authenticate 

pub fn authenticate(
    card: &IdCard,
    origin: &str,
    challenge_nonce: &[u8],
    pin1: &str,
) -> Result<AuthToken>
Authenticate with the ID card: sign the origin and challenge nonce with the authentication key (PIN1) and produce a Web eID authentication token.

origin is the ASCII serialization of the website origin of the relying party.

The signed data is hash(origin) || hash(challenge_nonce).